const path = require('path');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

module.exports = {
  entry: path.resolve(__dirname, './src/bundle.js'),
  resolve: {
    extensions: ['.marko', '.js'],
  },
  devtool: '#inline-source-map',
  output: {
    filename: 'bundle.js',
    path: path.resolve(__dirname, 'dist'),
  },
  devServer: {
    disableHostCheck: true,
    contentBase: path.join(__dirname, 'dist'),
    port: 2666,
  },
  module: {
    rules: [
      { test: /\.marko$/, use: [{ loader: '@marko/webpack/loader' }] },
      {
        test: /\.(sass|css)$/,
        use: ExtractTextPlugin.extract({
          fallback: 'style-loader',
          use: [
            {
              loader: 'css-loader?-autoprefixer?browsers=last 4 versions',
              options: {
                sourceMap: true,
              },
            },
            {
              loader: 'sass-loader',
              options: {
                data: '@import "imobcolors";',
                includePaths: [
                  path.join(
                    __dirname,
                    './node_modules/@kenlo/guidelines/src/sass/',
                  ),
                ],
                sourceMap: true,
              },
            },
          ],
        }),
      },
    ],
  },
  plugins: [
    new ExtractTextPlugin({ filename: 'style.css', allChunks: true }),
  ],
};
